@@ -43,7 +43,7 @@ Also see the TIE INTERFACE below.
 =cut
 package Cache;
 
-require 5.005;
+require 5.006;
 use strict;
 use warnings::register;
 use Carp;
@@ -54,7 +54,7 @@ use fields qw(
         default_expires removal_strategy size_limit
         load_callback validate_callback);
 
-our $VERSION = '2.01';
+our $VERSION = '2.02';
 
 our $EXPIRES_NOW = 'now';
 our $EXPIRES_NEVER = 'never';
@@ -381,7 +381,7 @@ sub set_validity {
 sub freeze {
     my Cache $self = shift;
     my $key = shift;
-    return $self->entry($key)->freeze();
+    return $self->entry($key)->freeze(@_);
 }
 
 =item $c->thaw( $key )
@@ -625,6 +625,6 @@ This module is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND,
 either expressed or implied. This program is free software; you can
 redistribute or modify it under the same terms as Perl itself.
 
-$Id: Cache.pm,v 1.3 2003/08/14 13:19:15 caleishm Exp $
+$Id: Cache.pm,v 1.5 2004/03/22 13:16:40 caleishm Exp $
 
 =cut
